==> jc-1.4.0.tar.gz: soot/toolkits/graph/Block__24AllMapTo.h <==
// class soot.toolkits.graph.Block$AllMapTo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class 4d7170b9288b2c69 soot_toolkits_graph_Block__24AllMapTo

// header file dependencies
// @dep_header java_util_AbstractMap

#include "java/util/AbstractMap.h"

#ifndef _JC_soot_toolkits_graph_Block__24AllMapTo_H_
#define _JC_soot_toolkits_graph_Block__24AllMapTo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;
struct _jc_soot_toolkits_graph_Block$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs	_jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs	_jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$refs	_jc_soot_toolkits_graph_Block__24AllMapTo$refs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs	_jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$object	_jc_soot_toolkits_graph_Block__24AllMapTo$object;

typedef const struct _jc_soot_toolkits_graph_Block__24AllMapTo$vmethods	_jc_soot_toolkits_graph_Block__24AllMapTo$vmethods;
typedef const struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtable	_jc_soot_toolkits_graph_Block__24AllMapTo$vtable;
typedef const struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtype	_jc_soot_toolkits_graph_Block__24AllMapTo$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_Block__24AllMapTo$method$_init$d43460c59a9e336e(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_graph_Block__24AllMapTo$method$entrySet$e1cf6e695274e51f(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_graph_Block__24AllMapTo$method$get$b30461fc5ea13399(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_Block__24AllMapTo$method_info$entrySet$e1cf6e695274e51f;
extern _jc_method _jc_soot_toolkits_graph_Block__24AllMapTo$method_info$get$b30461fc5ea13399;

// Virtual methods structure
struct _jc_soot_toolkits_graph_Block__24AllMapTo$vmethods {
	struct _jc_object	*(*entrySet$e1cf6e695274e51f)(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *);
	struct _jc_java_lang_Object$object	*(*get$b30461fc5ea13399)(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_soot_toolkits_graph_Block__24AllMapTo$vmethods	soot_toolkits_graph_Block__24AllMapTo;
};

// Vtype
struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_Block__24AllMapTo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs {
	struct _jc_java_lang_Object$object	*dest;
	struct _jc_soot_toolkits_graph_Block$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$refs {
    _jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs	soot_toolkits_graph_Block__24AllMapTo;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs	soot_toolkits_graph_Block__24AllMapTo;
};

// Object instance structure
struct _jc_soot_toolkits_graph_Block__24AllMapTo$object {
	_jc_soot_toolkits_graph_Block__24AllMapTo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_Block__24AllMapTo$vtype	*vtype;
	_jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_Block__24AllMapTo$vtype _jc_soot_toolkits_graph_Block__24AllMapTo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_Block__24AllMapTo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_Block__24AllMapTo$class_object;

#endif	/* _JC_soot_toolkits_graph_Block__24AllMapTo_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/Block__24AllMapTo.h <==
// class soot.toolkits.graph.Block$AllMapTo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class 4d7170b9288b2c69 soot_toolkits_graph_Block__24AllMapTo

// header file dependencies
// @dep_header java_util_AbstractMap

#include "java/util/AbstractMap.h"

#ifndef _JC_soot_toolkits_graph_Block__24AllMapTo_H_
#define _JC_soot_toolkits_graph_Block__24AllMapTo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;
struct _jc_soot_toolkits_graph_Block$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs	_jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs	_jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$refs	_jc_soot_toolkits_graph_Block__24AllMapTo$refs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs	_jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs;
typedef struct _jc_soot_toolkits_graph_Block__24AllMapTo$object	_jc_soot_toolkits_graph_Block__24AllMapTo$object;

typedef const struct _jc_soot_toolkits_graph_Block__24AllMapTo$vmethods	_jc_soot_toolkits_graph_Block__24AllMapTo$vmethods;
typedef const struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtable	_jc_soot_toolkits_graph_Block__24AllMapTo$vtable;
typedef const struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtype	_jc_soot_toolkits_graph_Block__24AllMapTo$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_Block__24AllMapTo$method$_init$d43460c59a9e336e(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_graph_Block__24AllMapTo$method$entrySet$e1cf6e695274e51f(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_graph_Block__24AllMapTo$method$get$b30461fc5ea13399(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_Block__24AllMapTo$method_info$entrySet$e1cf6e695274e51f;
extern _jc_method _jc_soot_toolkits_graph_Block__24AllMapTo$method_info$get$b30461fc5ea13399;

// Virtual methods structure
struct _jc_soot_toolkits_graph_Block__24AllMapTo$vmethods {
	struct _jc_object	*(*entrySet$e1cf6e695274e51f)(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$b30461fc5ea13399)(_jc_env *, struct _jc_soot_toolkits_graph_Block__24AllMapTo$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_soot_toolkits_graph_Block__24AllMapTo$vmethods	soot_toolkits_graph_Block__24AllMapTo;
};

// Vtype
struct _jc_soot_toolkits_graph_Block__24AllMapTo$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_Block__24AllMapTo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs {
	struct _jc_java_lang_Object$object	*dest;
	struct _jc_soot_toolkits_graph_Block$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$refs {
    _jc_soot_toolkits_graph_Block__24AllMapTo$sub_refs	soot_toolkits_graph_Block__24AllMapTo;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_soot_toolkits_graph_Block__24AllMapTo$sub_nonrefs	soot_toolkits_graph_Block__24AllMapTo;
};

// Object instance structure
struct _jc_soot_toolkits_graph_Block__24AllMapTo$object {
	_jc_soot_toolkits_graph_Block__24AllMapTo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_Block__24AllMapTo$vtype	*vtype;
	_jc_soot_toolkits_graph_Block__24AllMapTo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_Block__24AllMapTo$vtype _jc_soot_toolkits_graph_Block__24AllMapTo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_Block__24AllMapTo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_Block__24AllMapTo$class_object;

#endif	/* _JC_soot_toolkits_graph_Block__24AllMapTo_H_ */
